Changelog
---------

0.6.0 (2018-11-28)
~~~~~~~~~~~~~~~~~~~

- Adds an advisory deadline to the resource.
  [href]

0.5.1 (2018-03-30)
~~~~~~~~~~~~~~~~~~~

- Adds payable_reference property to reservations.
  [href]

- Requires Python 3.6.
  [href]

0.5.0 (2017-06-16)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to price resources and use payments for reservations.
  [href]

- Adds a custom allocation/reservation class.
  [href]

0.4.1 (2017-06-07)
~~~~~~~~~~~~~~~~~~~

- Adds support for libres 0.3.1.
  [href]

0.4.0 (2017-03-20)
~~~~~~~~~~~~~~~~~~~

- Renames package from onegov.libres to onegov.reservation to avoid ambiguity
  at the namespace level.
  [href]

0.3.0 (2016-06-24)
~~~~~~~~~~~~~~~~~~~

- Change highlighting from a list to a simple range.
  [href]

0.2.1 (2016-04-27)
~~~~~~~~~~~~~~~~~~~

- Simplifies access to the scheduler from the resource.
  [href]

0.2.0 (2016-04-13)
~~~~~~~~~~~~~~~~~~~

- Adds a group column to the resource.
  [href]

- Adds a view attribute to the resource.
  [href]

0.1.2 (2016-04-06)
~~~~~~~~~~~~~~~~~~~

- Adds compatibility with Morepath 0.13.
  [href]

0.1.1 (2016-01-28)
~~~~~~~~~~~~~~~~~~~

- Uses the latest onegov.core release to get rid of some code.
  [href]

0.1.0 (2015-10-12)
~~~~~~~~~~~~~~~~~~~

- Removes Python 2.x support.
  [href]

0.0.6 (2015-08-28)
~~~~~~~~~~~~~~~~~~~

- The form definition field no longer requires an e-mail address.
  [href]

0.0.5 (2015-08-26)
~~~~~~~~~~~~~~~~~~~

- Adds a form definition field to the resource model.
  [href]

0.0.4 (2015-08-20)
~~~~~~~~~~~~~~~~~~~

- Adds an allocation highlight function to the resource. Apps can use this for
  easy Morepath Path/UI integration.
  [href]

- Adds a convenience function to get the scheduler by resource id.
  [href]

0.0.3 (2015-08-05)
~~~~~~~~~~~~~~~~~~~

- Removes first/last hour setting.
  [href]

0.0.2 (2015-08-05)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to only delete if there are no reservations.
  [href]

0.0.1 (2015-08-03)
~~~~~~~~~~~~~~~~~~~

- Initial Release
